#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 exact-pi
version:              0.5.0.2
visibility:           public
id:                   exact-pi-0.5.0.2-7kDCc8FKRCX6YNIX0xAsIJ
key:                  exact-pi-0.5.0.2-7kDCc8FKRCX6YNIX0xAsIJ
license:              MIT
maintainer:           douglas.mcclean@gmail.com
author:               Douglas McClean
homepage:             https://github.com/dmcclean/exact-pi/
synopsis:             Exact rational multiples of pi (and integer powers of pi)
description:
    Provides an exact representation for rational multiples of pi alongside an approximate representation of all reals.
    Useful for storing and computing with conversion factors between physical units.

category:             Data
abi:                  c51f041c678b474c08a5c86de14159b0
exposed:              True
exposed-modules:      Data.ExactPi Data.ExactPi.TypeLevel
import-dirs:          /usr/lib/ghc-9.6.6/site-local/exact-pi-0.5.0.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/exact-pi-0.5.0.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/exact-pi-0.5.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-exact-pi
hs-libraries:         HSexact-pi-0.5.0.2-7kDCc8FKRCX6YNIX0xAsIJ
depends:
    base-4.18.2.1 numtype-dk-0.5.0.3-8Y8uzPE3pvRJbRmzxZil8Z

haddock-interfaces:   /usr/share/doc/haskell-exact-pi/html/exact-pi.haddock
haddock-html:         /usr/share/doc/haskell-exact-pi/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

